@@ -87,13 +87,16 @@ class Channel:
             return
 
         # initialize data
-        self.data = []
+        self.data = [float]
         # read all channel data
         for i in range(self.length):
             self.data.append(self.reader.read_double())                
 
 
     def plot(self):
+        """
+        Plot the channel over its connected time-channel.
+        """
         # cant plot time over time
         if self.isTime:
             print("\t[WARNING] Channel is time.")
@@ -107,6 +110,9 @@ class Channel:
         fig.show()
 
     def __str__(self):
+        """
+        Default conversion to string.
+        """
         print(self.name)
         for d in self.data:
             print(d)
\ No newline at end of file
